
# q-expansion of newform 930.2.h.d, downloaded from the LMFDB on 26 April 2024.

# We generate the q-expansion using the Hecke eigenvalues a_p at the primes.
# Each a_p is given as a linear combination
# of the following basis for the coefficient ring.

def make_data():

    from sage.all import prod, floor, prime_powers, gcd, QQ, primes_first_n, next_prime, RR

    def discrete_log(elts, gens, mod):
        # algorithm 2.2, page 16 of https://arxiv.org/abs/0903.2785
        def table_gens(gens, mod):
            T = [1]
            n = len(gens)
            r = [None]*n
            s = [None]*n
            for i in range(n):
                beta = gens[i]
                r[i] = 1
                N = len(T)
                while beta not in T:
                    for Tj in T[:N]:
                        T.append((beta*Tj) % mod)
                    beta = (beta*gens[i]) % mod
                    r[i] += 1
                s[i] = T.index(beta)
            return T, r, s
        T, r, s = table_gens(gens, mod)
        n = len(gens)
        N = [ prod(r[:j]) for j in range(n) ]
        Z = lambda s: [ (floor(s/N[j]) % r[j]) for j in range(n)]
        return [Z(T.index(elt % mod)) for elt in elts]
    def extend_multiplicatively(an):
        for pp in prime_powers(len(an)-1):
            for k in range(1, (len(an) - 1)//pp + 1):
                if gcd(k, pp) == 1:
                    an[pp*k] = an[pp]*an[k]
    from sage.all import PolynomialRing, NumberField, ZZ
    R = PolynomialRing(QQ, "x")
    f = R(poly_data)
    K = NumberField(f, "a")
    betas = [K([c/ZZ(den) for c in num]) for num, den in basis_data]
    convert_elt_to_field = lambda elt: sum(c*beta for c, beta in zip(elt, betas))
    # convert aps to K elements
    primes = primes_first_n(len(aps_data))
    good_primes = [p for p in primes if not p.divides(level)]
    aps = map(convert_elt_to_field, aps_data)
    if not hecke_ring_character_values:
        # trivial character
        char_values = dict(zip(good_primes, [1]*len(good_primes)))
    else:
        gens = [elt[0] for elt in hecke_ring_character_values]
        gens_values = [convert_elt_to_field(elt[1]) for elt in hecke_ring_character_values]
        char_values = dict([(
            p,prod(g**k for g, k in zip(gens_values, elt)))
            for p, elt in zip(good_primes, discrete_log(good_primes, gens, level))
            ])
    an_list_bound = next_prime(primes[-1])
    an = [0]*an_list_bound
    an[1] = 1
    
    from sage.all import PowerSeriesRing
    PS = PowerSeriesRing(K, "q")
    for p, ap in zip(primes, aps):
        if p.divides(level):
            euler_factor = [1, -ap]
        else:
            euler_factor = [1, -ap, p**(weight - 1) * char_values[p]]
        k = RR(an_list_bound).log(p).floor() + 1
        foo = (1/PS(euler_factor)).padded_list(k)
        for i in range(1, k):
            an[p**i] = foo[i]
    extend_multiplicatively(an)
    return PS(an)
level = 930
weight = 2
poly_data = [6561, 0, -2916, 0, 486, 0, 324, 0, -142, 0, 36, 0, 6, 0, -4, 0, 1]

# The entries in the following list give a basis for the
# coefficient ring in terms of a root of the defining polynomial above.
# Each line consists of the coefficients of the numerator, and a denominator.
basis_data  = [[[1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], 1], [[0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], 1], [[0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], 1], [[0, -57591, 0, -22113, 0, 2187, 0, -4355, 0, -63, 0, 111, 0, -101, 0, 5], 69984], [[-80919, 0, 1215, 0, 2187, 0, -4355, 0, -63, 0, 111, 0, -101, 0, 5, 0], 23328], [[0, -2916, 0, 486, 0, 324, 0, -142, 0, 36, 0, 6, 0, -4, 0, 1], 2187], [[-45927, 0, 5022, 0, 711, 0, -1826, 0, 369, 0, -42, 0, -65, 0, 14, 0], 11664], [[2916, 0, -486, 0, -324, 0, 142, 0, -36, 0, -6, 0, 4, 0, -1, 0], 729], [[-57591, 0, -10125, 0, -2493, 0, -1999, 0, -207, 0, -93, 0, -61, 0, -23, 0], 11664], [[20412, 0, -14499, 0, 54, 0, 997, 0, -684, 0, 21, 0, 22, 0, -19, 0], 5832], [[0, 45927, 0, -5022, 0, -711, 0, 1826, 0, -369, 0, 42, 0, 65, 0, -14], 11664], [[0, -5103, 0, -39123, 0, -2385, 0, -5, 0, -1575, 0, -51, 0, -17, 0, -61], 34992], [[0, -15390, 0, 4113, 0, 442, 0, -625, 0, 210, 0, -23, 0, -14, 0, 7], 3888], [[0, -117369, -138024, 64719, -1728, 2133, -1416, -4051, -3456, 3951, 504, -273, -192, -43, -168, 85], 69984], [[0, 508113, -138024, -120609, -1728, -10773, -1416, 23717, -3456, -6039, 504, 303, -192, 635, -168, -179], 69984], [[0, 508113, 138024, -120609, 1728, -10773, 1416, 23717, 3456, -6039, -504, 303, 192, 635, 168, -179], 69984]]

hecke_ring_character_values = [[311, [-1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0]], [187, [1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0]], [871, [-1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0]]]
aps_data = [[0, 0, 0, 0, 0, 0, -1, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -1, 0, 0, 0], [0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, -1, 0, 0, 0, 0, 0, 0], [0, 1, 0, 0, 0, -1, 0, 0, 0, 0, 1, -1, 1, 0, 0, 0], [0, -1, 0, 0, 0, -1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -2, 0, 0, 0, 0], [2, 0, -1, 0, 0, 0, 0, -1, 0, -1, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -1, 1, -1, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, -2, 1, -2, 1, -1], [-1, 0, 0, 0, 0, 0, 0, 0, 0, -2, 0, 0, 0, 0, -1, 0], [0, -4, 0, 2, 0, -4, 0, 0, 0, 0, 1, 0, -1, 0, -1, -1], [0, 0, -1, 0, 0, 0, -4, 1, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [-2, 0, 1, 0, -2, 0, -4, 1, -2, 0, 0, 0, 0, 0, 1, -1], [0, -3, 0, 0, 0, 3, 0, 0, 0, 0, 1, -1, 1, -2, 1, -1], [0, 0, 2, 0, 0, 0, 4, -2, 0, 0, 0, 0, 0, 0, 0, 0], [0, -2, 0, -2, 0, -2, 0, 0, 0, 0, 1, 0, -1, 0, 0, 0], [-4, 0, 2, 0, 0, 0, 0, 2, 0, -2, 0, 0, 0, 0, 1, -1], [2, 0, 1, 0, -3, 0, 2, -3, 2, 0, 0, 0, 0, 0, -1, 1], [0, 1, 0, 1, 0, 1, 0, 0, 0, 0, 2, 0, -2, 0, -1, -1], [0, 1, 0, 1, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 2, 2], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 0, 3, -4, 2, -2], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 3, 1, 0, 0, 0], [0, 0, -1, 0, 0, 0, 0, -1, 0, -2, 0, 0, 0, 0, 0, 0], [2, 0, -1, 0, -3, 0, -2, -1, 2, 0, 0, 0, 0, 0, -1, 1], [-2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -1, 1], [2, 0, -3, 0, 1, 0, 0, 1, 2, 0, 0, 0, 0, 0, -1, 1], [-6, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -2, 2], [4, 0, -4, 0, -1, 0, 2, 0, 4, 0, 0, 0, 0, 0, -2, 2], [0, -4, 0, 0, 0, -4, 0, 0, 0, 0, 2, 0, -2, 0, -1, -1], [0, 0, 2, 0, 0, 0, 0, -2, 0, 0, 0, 0, 0, 0, 0, 0], [0, 2, 0, 0, 0, -2, 0, 0, 0, 0, -2, -6, -2, 4, -2, 2], [0, 6, 0, 0, 0, 6, 0, 0, 0, 0, -1, 0, 1, 0, 3, 3], [-2, 0, -1, 0, 3, 0, -2, 3, -2, 0, 0, 0, 0, 0, 1, -1], [0, 0, 0, -4, 0, 0, 0, 0, 0, 0, 2, 0, -2, 0, 1, 1], [12, 0, -5, 0, 0, 0, 0, -5, 0, -5, 0, 0, 0, 0, -3, 3], [-4, 0, -2, 0, 0, 0, 0, -2, 0, 2, 0, 0, 0, 0, 1, -1], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -1, 1, -1, 0, 0, 0], [0, 0, 2, 0, -4, 0, -2, -2, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -5, 6, -5, 4, -2, 2], [0, 4, 0, 1, 0, 4, 0, 0, 0, 0, -2, 0, 2, 0, 0, 0], [8, 0, -3, 0, -2, 0, 6, -5, 8, 0, 0, 0, 0, 0, -4, 4], [-4, 0, 4, 0, 0, 0, 0, 4, 0, 2, 0, 0, 0, 0, 1, -1], [0, 4, 0, 0, 0, -4, 0, 0, 0, 0, 3, -6, 3, 2, -1, 1], [0, 1, 0, -5, 0, 1, 0, 0, 0, 0, -4, 0, 4, 0, 0, 0], [-10, 0, -1, 0, 0, 0, 0, -1, 0, -5, 0, 0, 0, 0, 0, 0], [0, -4, 0, 0, 0, -4, 0, 0, 0, 0, -2, 0, 2, 0, 1, 1], [-2, 0, 5, 0, -1, 0, 0, -3, -2, 0, 0, 0, 0, 0, 1, -1], [0, 1, 0, -1, 0, 1, 0, 0, 0, 0, -5, 0, 5, 0, 1, 1], [-4, 0, 2, 0, 1, 0, -2, 2, -4, 0, 0, 0, 0, 0, 2, -2], [0, -6, 0, 0, 0, 6, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, -4, 0, 0, 0, -4, 0, 0, 0, 0, -2, 0, 2, 0, 0, 0], [0, -1, 0, 0, 0, 1, 0, 0, 0, 0, 4, 6, 4, -6, 3, -3], [0, 0, -3, 0, 5, 0, -6, 3, 0, 0, 0, 0, 0, 0, 0, 0], [0, 4, 0, 0, 0, -4, 0, 0, 0, 0, 0, 4, 0, 2, -1, 1], [0, 1, 0, 0, 0, -1, 0, 0, 0, 0, -4, 2, -4, 4, -2, 2], [0, 5, 0, 5, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 2, 2], [0, -1, 0, 0, 0, -1, 0, 0, 0, 0, -8, 0, 8, 0, 0, 0], [-2, 0, 0, 0, -6, 0, 0, 2, -2, 0, 0, 0, 0, 0, 1, -1], [0, 0, -4, 0, 0, 0, 0, -4, 0, 0, 0, 0, 0, 0, -3, 3], [-4, 0, 6, 0, 0, 0, 10, -2, -4, 0, 0, 0, 0, 0, 2, -2], [-8, 0, 6, 0, 0, 0, 0, 6, 0, 8, 0, 0, 0, 0, 5, -5], [2, 0, 0, 0, -2, 0, 10, -2, 2, 0, 0, 0, 0, 0, -1, 1], [0, 2, 0, -4, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, -2, -2], [-4, 0, 2, 0, 0, 0, 2, 2, -4, 0, 0, 0, 0, 0, 2, -2], [0, 4, 0, 10, 0, 4, 0, 0, 0, 0, 1, 0, -1, 0, 1, 1], [0, -2, 0, -8, 0, -2, 0, 0, 0, 0, 6, 0, -6, 0, -2, -2], [0, -8, 0, 0, 0, 8, 0, 0, 0, 0, 1, 0, 1, 0, 0, 0], [-18, 0, 0, 0, 0, 0, 0, 0, 0, 4, 0, 0, 0, 0, 0, 0], [0, -6, 0, 0, 0, 6, 0, 0, 0, 0, -6, 0, -6, 0, 0, 0], [6, 0, -2, 0, 3, 0, -10, -4, 6, 0, 0, 0, 0, 0, -3, 3], [0, 6, 0, -2, 0, 6, 0, 0, 0, 0, -4, 0, 4, 0, -1, -1], [-4, 0, -1, 0, 0, 0, 0, -1, 0, -5, 0, 0, 0, 0, 3, -3], [6, 0, -1, 0, 0, 0, 0, -1, 0, 3, 0, 0, 0, 0, -4, 4], [0, 4, 0, 0, 0, -4, 0, 0, 0, 0, 0, 0, 0, -2, 1, -1], [0, -3, 0, 0, 0, 3, 0, 0, 0, 0, 6, 8, 6, 0, 0, 0], [-12, 0, -3, 0, 0, 0, 0, -3, 0, 7, 0, 0, 0, 0, 1, -1], [0, 2, 0, 0, 0, -2, 0, 0, 0, 0, -9, 1, -9, 0, 0, 0], [0, -2, 0, 2, 0, -2, 0, 0, 0, 0, 2, 0, -2, 0, 2, 2], [4, 0, 0, 0, 4, 0, 12, -4, 4, 0, 0, 0, 0, 0, -2, 2], [2, 0, 2, 0, 0, 0, 0, 2, 0, -4, 0, 0, 0, 0, 2, -2], [0, 0, 1, 0, -2, 0, -18, -1, 0, 0, 0, 0, 0, 0, 0, 0], [0, 1, 0, 13, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 3, 3], [6, 0, -3, 0, 0, 0, 0, -3, 0, 2, 0, 0, 0, 0, 0, 0], [6, 0, 1, 0, 5, 0, 8, -7, 6, 0, 0, 0, 0, 0, -3, 3], [0, 4, 0, 0, 0, -4, 0, 0, 0, 0, -2, -2, -2, -2, 1, -1], [0, -6, 0, 8, 0, -6, 0, 0, 0, 0, 8, 0, -8, 0, -2, -2], [0, 1, 0, 0, 0, -1, 0, 0, 0, 0, 10, 0, 10, -8, 4, -4], [0, 4, 0, 6, 0, 4, 0, 0, 0, 0, -6, 0, 6, 0, -1, -1], [0, 0, -2, 0, 0, 0, 20, 2, 0, 0, 0, 0, 0, 0, 0, 0], [12, 0, -5, 0, -1, 0, 18, -7, 12, 0, 0, 0, 0, 0, -6, 6], [0, 8, 0, -8, 0, 8, 0, 0, 0, 0, -2, 0, 2, 0, -1, -1], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, 2, -10, 5, -5], [0, 1, 0, 2, 0, 1, 0, 0, 0, 0, -2, 0, 2, 0, 2, 2], [-2, 0, 4, 0, 0, 0, 4, -2, -2, 0, 0, 0, 0, 0, 1, -1], [0, -1, 0, 0, 0, 1, 0, 0, 0, 0, -4, -2, -4, 4, -2, 2], [10, 0, -4, 0, -2, 0, 8, -6, 10, 0, 0, 0, 0, 0, -5, 5], [0, 2, 0, 13, 0, 2, 0, 0, 0, 0, 4, 0, -4, 0, -2, -2], [2, 0, 2, 0, 0, 0, 0, 2, 0, 6, 0, 0, 0, 0, 2, -2], [0, 0, 2, 0, 0, 0, 0, 2, 0, 6, 0, 0, 0, 0, 3, -3], [0, -8, 0, 0, 0, 8, 0, 0, 0, 0, -4, 3, -4, 0, 0, 0], [4, 0, -6, 0, 0, 0, -4, 2, 4, 0, 0, 0, 0, 0, -2, 2], [0, 2, 0, 0, 0, -2, 0, 0, 0, 0, 7, -3, 7, 0, 0, 0], [0, -5, 0, 6, 0, -5, 0, 0, 0, 0, -6, 0, 6, 0, 2, 2], [20, 0, -3, 0, 0, 0, 0, -3, 0, 2, 0, 0, 0, 0, -2, 2], [0, 1, 0, 0, 0, -1, 0, 0, 0, 0, -14, 12, -14, 2, -1, 1], [-6, 0, 1, 0, 4, 0, -26, 5, -6, 0, 0, 0, 0, 0, 3, -3], [-10, 0, 2, 0, -3, 0, -2, 8, -10, 0, 0, 0, 0, 0, 5, -5], [0, -10, 0, 2, 0, -10, 0, 0, 0, 0, -4, 0, 4, 0, -2, -2], [2, 0, 3, 0, 0, 0, 0, 3, 0, 3, 0, 0, 0, 0, -2, 2], [0, -2, 0, -4, 0, -2, 0, 0, 0, 0, 3, 0, -3, 0, -3, -3], [2, 0, -3, 0, 7, 0, -10, 1, 2, 0, 0, 0, 0, 0, -1, 1], [0, -1, 0, -8, 0, -1, 0, 0, 0, 0, 6, 0, -6, 0, -2, -2], [0, -7, 0, 1, 0, -7, 0, 0, 0, 0, -4, 0, 4, 0, -4, -4], [0, 4, 0, 0, 0, -4, 0, 0, 0, 0, 2, -6, 2, 10, -5, 5], [0, 3, 0, -3, 0, 3, 0, 0, 0, 0, 9, 0, -9, 0, -1, -1], [0, 4, 0, 0, 0, -4, 0, 0, 0, 0, 7, -5, 7, 8, -4, 4], [4, 0, -4, 0, 2, 0, 6, 0, 4, 0, 0, 0, 0, 0, -2, 2], [-4, 0, 0, 0, -8, 0, -12, 4, -4, 0, 0, 0, 0, 0, 2, -2], [-10, 0, 8, 0, 0, 0, 0, 8, 0, 2, 0, 0, 0, 0, 4, -4], [0, -12, 0, 0, 0, -12, 0, 0, 0, 0, 6, 0, -6, 0, -2, -2], [0, 7, 0, 0, 0, -7, 0, 0, 0, 0, -7, -5, -7, -2, 1, -1], [14, 0, -7, 0, -7, 0, 16, -7, 14, 0, 0, 0, 0, 0, -7, 7], [6, 0, -1, 0, 0, 0, 0, -1, 0, 3, 0, 0, 0, 0, 0, 0], [-6, 0, 5, 0, -11, 0, -10, 1, -6, 0, 0, 0, 0, 0, 3, -3], [0, 0, 0, -3, 0, 0, 0, 0, 0, 0, 6, 0, -6, 0, -2, -2], [0, 6, 0, 0, 0, -6, 0, 0, 0, 0, 12, -6, 12, 4, -2, 2], [-10, 0, 1, 0, 0, 0, 0, 1, 0, 5, 0, 0, 0, 0, 4, -4], [22, 0, 2, 0, 0, 0, 0, 2, 0, 2, 0, 0, 0, 0, 5, -5], [0, -2, 0, -12, 0, -2, 0, 0, 0, 0, -9, 0, 9, 0, 1, 1], [0, 6, 0, 0, 0, -6, 0, 0, 0, 0, 7, -11, 7, 4, -2, 2], [10, 0, -1, 0, 0, 0, 0, -1, 0, -6, 0, 0, 0, 0, -4, 4], [0, -8, 0, 6, 0, -8, 0, 0, 0, 0, 1, 0, -1, 0, -7, -7], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, -5, 3, 8, -4, 4], [-10, 0, 0, 0, 0, 0, 0, 0, 0, -13, 0, 0, 0, 0, -2, 2], [0, 11, 0, 0, 0, -11, 0, 0, 0, 0, -5, 1, -5, 2, -1, 1], [0, 15, 0, -11, 0, 15, 0, 0, 0, 0, -11, 0, 11, 0, 5, 5], [0, 4, 0, 0, 0, -4, 0, 0, 0, 0, -5, 6, -5, 2, -1, 1], [0, 6, 0, 0, 0, -6, 0, 0, 0, 0, -7, -13, -7, 4, -2, 2], [-14, 0, 5, 0, 0, 0, 0, 5, 0, -1, 0, 0, 0, 0, 4, -4], [0, 8, 0, 0, 0, -8, 0, 0, 0, 0, 1, 0, 1, 2, -1, 1], [0, -4, 0, 0, 0, -4, 0, 0, 0, 0, 6, 0, -6, 0, -3, -3], [0, -11, 0, 0, 0, 11, 0, 0, 0, 0, 8, 10, 8, 2, -1, 1], [0, -2, 0, -7, 0, -2, 0, 0, 0, 0, 6, 0, -6, 0, 0, 0], [-6, 0, 8, 0, -5, 0, 6, -2, -6, 0, 0, 0, 0, 0, 3, -3], [12, 0, -9, 0, 0, 0, 0, -9, 0, -9, 0, 0, 0, 0, -7, 7], [8, 0, -8, 0, 16, 0, -14, 0, 8, 0, 0, 0, 0, 0, -4, 4], [0, -1, 0, -8, 0, -1, 0, 0, 0, 0, -6, 0, 6, 0, 4, 4], [0, -4, 0, 0, 0, 4, 0, 0, 0, 0, -11, -11, -11, 8, -4, 4], [-14, 0, -2, 0, 0, 0, 0, -2, 0, -6, 0, 0, 0, 0, 1, -1], [0, -8, 0, 0, 0, 8, 0, 0, 0, 0, -4, 6, -4, -6, 3, -3], [0, 9, 0, -1, 0, 9, 0, 0, 0, 0, 3, 0, -3, 0, 1, 1], [-6, 0, 7, 0, -2, 0, 4, -1, -6, 0, 0, 0, 0, 0, 3, -3], [-8, 0, -4, 0, 0, 0, 0, -4, 0, 4, 0, 0, 0, 0, -5, 5], [0, 2, 0, 0, 0, -2, 0, 0, 0, 0, -2, -16, -2, 4, -2, 2], [12, 0, -10, 0, 0, 0, 0, -10, 0, -10, 0, 0, 0, 0, -8, 8], [0, -4, 0, 0, 0, 4, 0, 0, 0, 0, 3, 3, 3, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 10, 0, 0, 0, 0, 5, -5], [0, 5, 0, 0, 0, -5, 0, 0, 0, 0, -10, 16, -10, 8, -4, 4], [0, -8, 0, 0, 0, 8, 0, 0, 0, 0, -5, 12, -5, -4, 2, -2], [0, 2, 0, 0, 0, -2, 0, 0, 0, 0, 20, -4, 20, -4, 2, -2], [0, -14, 0, 2, 0, -14, 0, 0, 0, 0, 6, 0, -6, 0, -1, -1], [16, 0, -2, 0, -4, 0, 8, -14, 16, 0, 0, 0, 0, 0, -8, 8], [-6, 0, 6, 0, 12, 0, 2, 0, -6, 0, 0, 0, 0, 0, 3, -3], [0, -4, 0, 0, 0, 4, 0, 0, 0, 0, 4, 0, 4, 10, -5, 5], [0, -9, 0, -5, 0, -9, 0, 0, 0, 0, 18, 0, -18, 0, -4, -4], [-18, 0, 4, 0, 0, 0, 0, 4, 0, 6, 0, 0, 0, 0, -1, 1]]
